==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/TIDataConnector.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin

import com.pulumi.azurenative.securityinsights.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.securityinsights.kotlin.outputs.TIDataConnectorDataTypesResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import com.pulumi.azurenative.securityinsights.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin
import com.pulumi.azurenative.securityinsights.kotlin.outputs.TIDataConnectorDataTypesResponse.Companion.toKotlin as tIDataConnectorDataTypesResponseToKotlin

/**
 * Builder for [TIDataConnector].
 */
@PulumiTagMarker
public class TIDataConnectorResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: TIDataConnectorArgs = TIDataConnectorArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend TIDataConnectorArgsBuilder.() -> Unit) {
        val builder = TIDataConnectorArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): TIDataConnector {
        val builtJavaResource =
            com.pulumi.azurenative.securityinsights.TIDataConnector(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return TIDataConnector(builtJavaResource)
    }
}

/**
 * Represents threat intelligence data connector.
 * Azure REST API version: 2023-02-01. Prior API version in Azure Native 1.x: 2020-01-01.
 * ## Example Usage
 * ### Creates or updates an Office365 data connector.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var tiDataConnector = new AzureNative.SecurityInsights.TIDataConnector("tiDataConnector", new()
 *     {
 *         DataConnectorId = "73e01a99-5cd7-4139-a149-9f2736ff2ab5",
 *         ResourceGroupName = "myRg",
 *         WorkspaceName = "myWorkspace",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/securityinsights/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := securityinsights.NewTIDataConnector(ctx, "tiDataConnector", &securityinsights.TIDataConnectorArgs{
 * 			DataConnectorId:   pulumi.String("73e01a99-5cd7-4139-a149-9f2736ff2ab5"),
 * 			ResourceGroupName: pulumi.String("myRg"),
 * 			WorkspaceName:     pulumi.String("myWorkspace"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.securityinsights.TIDataConnector;
 * import com.pulumi.azurenative.securityinsights.TIDataConnectorArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var tiDataConnector = new TIDataConnector("tiDataConnector", TIDataConnectorArgs.builder()
 *             .dataConnectorId("73e01a99-5cd7-4139-a149-9f2736ff2ab5")
 *             .resourceGroupName("myRg")
 *             .workspaceName("myWorkspace")
 *             .build());
 *     }
 * }
 * ```
 * ### Creates or updates an Threat Intelligence Platform data connector.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var tiDataConnector = new AzureNative.SecurityInsights.TIDataConnector("tiDataConnector", new()
 *     {
 *         DataConnectorId = "73e01a99-5cd7-4139-a149-9f2736ff2ab5",
 *         DataTypes = new AzureNative.SecurityInsights.Inputs.TIDataConnectorDataTypesArgs
 *         {
 *             Indicators = new AzureNative.SecurityInsights.Inputs.TIDataConnectorDataTypesIndicatorsArgs
 *             {
 *                 State = "Enabled",
 *             },
 *         },
 *         Kind = "ThreatIntelligence",
 *         ResourceGroupName = "myRg",
 *         TenantId = "06b3ccb8-1384-4bcc-aec7-852f6d57161b",
 *         TipLookbackPeriod = "2020-01-01T13:00:30.123Z",
 *         WorkspaceName = "myWorkspace",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/securityinsights/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := securityinsights.NewTIDataConnector(ctx, "tiDataConnector", &securityinsights.TIDataConnectorArgs{
 * 			DataConnectorId: pulumi.String("73e01a99-5cd7-4139-a149-9f2736ff2ab5"),
 * 			DataTypes: securityinsights.TIDataConnectorDataTypesResponse{
 * 				Indicators: &securityinsights.TIDataConnectorDataTypesIndicatorsArgs{
 * 					State: pulumi.String("Enabled"),
 * 				},
 * 			},
 * 			Kind:              pulumi.String("ThreatIntelligence"),
 * 			ResourceGroupName: pulumi.String("myRg"),
 * 			TenantId:          pulumi.String("06b3ccb8-1384-4bcc-aec7-852f6d57161b"),
 * 			TipLookbackPeriod: pulumi.String("2020-01-01T13:00:30.123Z"),
 * 			WorkspaceName:     pulumi.String("myWorkspace"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.securityinsights.TIDataConnector;
 * import com.pulumi.azurenative.securityinsights.TIDataConnectorArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var tiDataConnector = new TIDataConnector("tiDataConnector", TIDataConnectorArgs.builder()
 *             .dataConnectorId("73e01a99-5cd7-4139-a149-9f2736ff2ab5")
 *             .dataTypes(Map.of("indicators", Map.of("state", "Enabled")))
 *             .kind("ThreatIntelligence")
 *             .resourceGroupName("myRg")
 *             .tenantId("06b3ccb8-1384-4bcc-aec7-852f6d57161b")
 *             .tipLookbackPeriod("2020-01-01T13:00:30.123Z")
 *             .workspaceName("myWorkspace")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:securityinsights:TIDataConnector 73e01a99-5cd7-4139-a149-9f2736ff2ab5 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.OperationalInsights/workspaces/{workspaceName}/providers/Microsoft.SecurityInsights/dataConnectors/{dataConnectorId}
 * ```
 */
public class TIDataConnector internal constructor(
    override val javaResource: com.pulumi.azurenative.securityinsights.TIDataConnector,
) : KotlinCustomResource(javaResource, TIDataConnectorMapper) {
    /**
     * The available data types for the connector.
     */
    public val dataTypes: Output<TIDataConnectorDataTypesResponse>?
        get() = javaResource.dataTypes().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    tIDataConnectorDataTypesResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * Etag of the azure resource
     */
    public val etag: Output<String>?
        get() = javaResource.etag().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The kind of the data connector
     * Expected value is 'ThreatIntelligence'.
     */
    public val kind: Output<String>
        get() = javaResource.kind().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * The tenant id to connect to, and get the data from.
     */
    public val tenantId: Output<String>?
        get() = javaResource.tenantId().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The lookback period for the feed to be imported.
     */
    public val tipLookbackPeriod: Output<String>?
        get() = javaResource.tipLookbackPeriod().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object TIDataConnectorMapper : ResourceMapper<TIDataConnector> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.securityinsights.TIDataConnector::class == javaResource::class

    override fun map(javaResource: Resource): TIDataConnector = TIDataConnector(
        javaResource as
            com.pulumi.azurenative.securityinsights.TIDataConnector,
    )
}

/**
 * @see [TIDataConnector].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [TIDataConnector].
 */
public suspend fun tiDataConnector(
    name: String,
    block: suspend TIDataConnectorResourceBuilder.() -> Unit,
): TIDataConnector {
    val builder = TIDataConnectorResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [TIDataConnector].
 * @param name The _unique_ name of the resulting resource.
 */
public fun tiDataConnector(name: String): TIDataConnector {
    val builder = TIDataConnectorResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/TIDataConnector.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin

import com.pulumi.azurenative.securityinsights.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.securityinsights.kotlin.outputs.TIDataConnectorDataTypesResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import com.pulumi.azurenative.securityinsights.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin
import com.pulumi.azurenative.securityinsights.kotlin.outputs.TIDataConnectorDataTypesResponse.Companion.toKotlin as tIDataConnectorDataTypesResponseToKotlin

/**
 * Builder for [TIDataConnector].
 */
@PulumiTagMarker
public class TIDataConnectorResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: TIDataConnectorArgs = TIDataConnectorArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend TIDataConnectorArgsBuilder.() -> Unit) {
        val builder = TIDataConnectorArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): TIDataConnector {
        val builtJavaResource =
            com.pulumi.azurenative.securityinsights.TIDataConnector(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return TIDataConnector(builtJavaResource)
    }
}

/**
 * Represents threat intelligence data connector.
 * Azure REST API version: 2023-02-01. Prior API version in Azure Native 1.x: 2020-01-01.
 * ## Example Usage
 * ### Creates or updates an Office365 data connector.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var tiDataConnector = new AzureNative.SecurityInsights.TIDataConnector("tiDataConnector", new()
 *     {
 *         DataConnectorId = "73e01a99-5cd7-4139-a149-9f2736ff2ab5",
 *         ResourceGroupName = "myRg",
 *         WorkspaceName = "myWorkspace",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/securityinsights/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := securityinsights.NewTIDataConnector(ctx, "tiDataConnector", &securityinsights.TIDataConnectorArgs{
 * 			DataConnectorId:   pulumi.String("73e01a99-5cd7-4139-a149-9f2736ff2ab5"),
 * 			ResourceGroupName: pulumi.String("myRg"),
 * 			WorkspaceName:     pulumi.String("myWorkspace"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.securityinsights.TIDataConnector;
 * import com.pulumi.azurenative.securityinsights.TIDataConnectorArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var tiDataConnector = new TIDataConnector("tiDataConnector", TIDataConnectorArgs.builder()
 *             .dataConnectorId("73e01a99-5cd7-4139-a149-9f2736ff2ab5")
 *             .resourceGroupName("myRg")
 *             .workspaceName("myWorkspace")
 *             .build());
 *     }
 * }
 * ```
 * ### Creates or updates an Threat Intelligence Platform data connector.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var tiDataConnector = new AzureNative.SecurityInsights.TIDataConnector("tiDataConnector", new()
 *     {
 *         DataConnectorId = "73e01a99-5cd7-4139-a149-9f2736ff2ab5",
 *         DataTypes = new AzureNative.SecurityInsights.Inputs.TIDataConnectorDataTypesArgs
 *         {
 *             Indicators = new AzureNative.SecurityInsights.Inputs.TIDataConnectorDataTypesIndicatorsArgs
 *             {
 *                 State = AzureNative.SecurityInsights.DataTypeState.Enabled,
 *             },
 *         },
 *         Kind = "ThreatIntelligence",
 *         ResourceGroupName = "myRg",
 *         TenantId = "06b3ccb8-1384-4bcc-aec7-852f6d57161b",
 *         TipLookbackPeriod = "2020-01-01T13:00:30.123Z",
 *         WorkspaceName = "myWorkspace",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/securityinsights/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := securityinsights.NewTIDataConnector(ctx, "tiDataConnector", &securityinsights.TIDataConnectorArgs{
 * 			DataConnectorId: pulumi.String("73e01a99-5cd7-4139-a149-9f2736ff2ab5"),
 * 			DataTypes: &securityinsights.TIDataConnectorDataTypesArgs{
 * 				Indicators: &securityinsights.TIDataConnectorDataTypesIndicatorsArgs{
 * 					State: pulumi.String(securityinsights.DataTypeStateEnabled),
 * 				},
 * 			},
 * 			Kind:              pulumi.String("ThreatIntelligence"),
 * 			ResourceGroupName: pulumi.String("myRg"),
 * 			TenantId:          pulumi.String("06b3ccb8-1384-4bcc-aec7-852f6d57161b"),
 * 			TipLookbackPeriod: pulumi.String("2020-01-01T13:00:30.123Z"),
 * 			WorkspaceName:     pulumi.String("myWorkspace"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.securityinsights.TIDataConnector;
 * import com.pulumi.azurenative.securityinsights.TIDataConnectorArgs;
 * import com.pulumi.azurenative.securityinsights.inputs.TIDataConnectorDataTypesArgs;
 * import com.pulumi.azurenative.securityinsights.inputs.TIDataConnectorDataTypesIndicatorsArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var tiDataConnector = new TIDataConnector("tiDataConnector", TIDataConnectorArgs.builder()
 *             .dataConnectorId("73e01a99-5cd7-4139-a149-9f2736ff2ab5")
 *             .dataTypes(TIDataConnectorDataTypesArgs.builder()
 *                 .indicators(TIDataConnectorDataTypesIndicatorsArgs.builder()
 *                     .state("Enabled")
 *                     .build())
 *                 .build())
 *             .kind("ThreatIntelligence")
 *             .resourceGroupName("myRg")
 *             .tenantId("06b3ccb8-1384-4bcc-aec7-852f6d57161b")
 *             .tipLookbackPeriod("2020-01-01T13:00:30.123Z")
 *             .workspaceName("myWorkspace")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:securityinsights:TIDataConnector 73e01a99-5cd7-4139-a149-9f2736ff2ab5 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.OperationalInsights/workspaces/{workspaceName}/providers/Microsoft.SecurityInsights/dataConnectors/{dataConnectorId}
 * ```
 */
public class TIDataConnector internal constructor(
    override val javaResource: com.pulumi.azurenative.securityinsights.TIDataConnector,
) : KotlinCustomResource(javaResource, TIDataConnectorMapper) {
    /**
     * The available data types for the connector.
     */
    public val dataTypes: Output<TIDataConnectorDataTypesResponse>?
        get() = javaResource.dataTypes().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    tIDataConnectorDataTypesResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * Etag of the azure resource
     */
    public val etag: Output<String>?
        get() = javaResource.etag().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The kind of the data connector
     * Expected value is 'ThreatIntelligence'.
     */
    public val kind: Output<String>
        get() = javaResource.kind().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * The tenant id to connect to, and get the data from.
     */
    public val tenantId: Output<String>?
        get() = javaResource.tenantId().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The lookback period for the feed to be imported.
     */
    public val tipLookbackPeriod: Output<String>?
        get() = javaResource.tipLookbackPeriod().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object TIDataConnectorMapper : ResourceMapper<TIDataConnector> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.securityinsights.TIDataConnector::class == javaResource::class

    override fun map(javaResource: Resource): TIDataConnector = TIDataConnector(
        javaResource as
            com.pulumi.azurenative.securityinsights.TIDataConnector,
    )
}

/**
 * @see [TIDataConnector].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [TIDataConnector].
 */
public suspend fun tiDataConnector(
    name: String,
    block: suspend TIDataConnectorResourceBuilder.() -> Unit,
): TIDataConnector {
    val builder = TIDataConnectorResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [TIDataConnector].
 * @param name The _unique_ name of the resulting resource.
 */
public fun tiDataConnector(name: String): TIDataConnector {
    val builder = TIDataConnectorResourceBuilder()
    builder.name(name)
    return builder.build()
}
